/*
 * @Description: 生产工具信息
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-07-04 11:21:28
 */

import { Ref, h, unref } from 'vue';
import { DeleteEntity, GetEnum, getEntity } from '/@/api/tigerapi/system';
import { ActionItem, BasicColumn, FormSchema, useTable } from '/@/components/Table';
import { isNullOrEmpty, isNullOrUnDef } from '/@/utils/is';
import { buildUUID } from '/@/utils/uuid';
import { useUserStore } from '/@/store/modules/user';
import { formatToDateTime } from '/@/utils/dateUtil';
import { Tag } from 'ant-design-vue';
import { useLocale } from '/@/locales/useLocale';
import { useDrawer } from '/@/components/Drawer';
import { EditOperation, Search, custDel } from '../data';

const { getLocale } = useLocale();
function _default() {
  const ActionColumn: BasicColumn = {
    width: 80,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: undefined,
  };
  
  /**
   * @description: 些自定义方法
   * @return {*}
   */
  const methods = {
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (type: string) => {
      return {
        action: 'drawer', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
      };
    },
    /**
     * @description: 操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      if (!isNullOrUnDef(data[1])) {
        data[1].popConfirm.confirm = custDel.bind(null, args, params);
      }
      return data;
    },
    /**
     * @description: 高级表单和详情页面返回主页面的url
     * @return {*}
     */
    GetHomeUrl: () => {
      const param = { ID: 'MES_TOOL',EntityName: 'MES_TOOL', colSlots: [], crudColSlots: [] };
      return `/MES_TOOL/LC/${encodeURI(JSON.stringify(param))}`;
    },
    GetBaseColumns: (type: string) => {
      return baseColumns[type];
    },
    GetSearchForm: (type: string) => {
      return searchForms[type];
    },
    GetCrudForm: (type: string) => {
      return crudForms[type];
    },
    //主表 生产工具信息
    GetBaseForm: (entityName:string, isedit: boolean) => {
      return [
        {
          field: 'TOOL_CODE',
          label: '工具编码',
          component: 'Input',
          required: true,
          colProps: {
            span: 8,
          },
          dynamicDisabled: ({ values }) => {
            return isedit? true: false;
          },
        },
        {
          label: '工具型号',
          field: 'TOOL_MODEL',
          required: true,
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '工具规格',
          field: 'TOOL_SPEC',
          required: true,
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '工具类型',
          field: 'TOOL_TYPE',
          required: true,
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '设备状态',
          field: 'STATUS',
          component: 'ApiSelect',
          colProps: { span: 8 },
          defaultValue: 0,
          componentProps: {
            api: GetEnum,
            params: { name: 'MES_TOOL+STATUSs' },
            resultField: 'Data',
            labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
            valueField: 'Value',
            // onChange: (e, v) => {
            //   alert(e)
            //   console.log('ApiSelect====>:', e, v);
            // },
          },
        },
        {
          label: '生产厂家',
          field: 'MFT_NAME',
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '生产日期',
          field: 'MFT_DATE',
          component: 'DatePicker',
          colProps: {
            span: 8,
          },
        },
        {
          label: '使用部门',
          field: 'USE_DEPT',
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '工厂编码',
          field: 'FTY_CODE',
          required: true,
          component: 'ApiSelect',
          colProps: {
            span: 8,
          },
          componentProps: {
            api: getEntity,
            params: { entityName: 'MES_FACTORY', sqlcmd: ' 1=1 ' },
            resultField: 'Data.Items',
            labelField: 'FTY_NAME',
            valueField: 'FTY_CODE',
          },
          // dynamicDisabled: ({ values }) => {
          //   return true;
          // },
        },
        {
          label: '车间编码',
          field: 'WS_CODE',
          required: true,
          component: 'ApiSelect',
          colProps: {
            span: 8,
          },
          componentProps: {
            api: getEntity,
            params: { entityName: 'MES_WORKSHOP', sqlcmd: ' 1=1 ' },
            resultField: 'Data.Items',
            labelField: 'WS_NAME',
            valueField: 'WS_CODE',
          },
          // dynamicDisabled: ({ values }) => {
          //   return true;
          // },
        },
        {
          label: '产线编码',
          field: 'LINE_CODE',
          required: true,
          component: 'ApiSelect',
          colProps: {
            span: 8,
          },
          componentProps: {
            api: getEntity,
            params: { entityName: 'MES_LINE', sqlcmd: ' 1=1 ' },
            resultField: 'Data.Items',
            labelField: 'LINE_NAME',
            valueField: 'LINE_CODE',
          },
          // dynamicDisabled: ({ values }) => {
          //   return true;
          // },
        },
        {
          label: '使用地点',
          field: 'LOCATION',
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '使用次数上限',
          field: 'USE_LIMIT',
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: '备注',
          field: 'REMARK',
          component: 'Input',
          colProps: {
            span: 8,
          },
        },
        {
          label: 'ID',
          field: 'ID',
          component: 'Input',
          colProps: {
            span: 8,
          },
          show: false,
        },
      ];
    },
    /**
     * @description: 获取卡片内配置列表，以循环显示多个卡片并配置多个插槽
     * @return {*}
     */    
    GetBaseCards: (type: string) => {
      return [
        {
          name: 'BaseForm',
          slots: [],
          preIcons: {},
          title: '生产工具信息',
          entityName: 'MES_TOOL',
        },
        // {
        //   name: 'prodinfo',
        //   slots: ['addRot', 'setRot'],
        //   preIcons: { addRot: 'search|svg', setRot: 'config|svg' },
        //   title: '产品信息',
        // },
        // { name: 'rotinfo', slots: ['add'], preIcons: { add: 'search|svg' }, title: '工艺信息' },
      ];
    },
    /**
     * @description: 获取右侧边框use方法
     * @return {*}
     */    
    GetUseDrawers: () => {
      return [{
        'MES_TOOL_PROP': useDrawer(),
      }];
    },
    /**
     * @description: 获取表格use列表
     * @param {string} type
     * @param {array} args
     * @return {*}
     */    
    GetUseTables: (data: Ref<{}>, ...args) => {
      return {
        MES_TOOL_PROP: useTable({
          title: '列表信息',
          dataSource: data.value['MES_TOOL_PROP'],
          columns: baseColumns['MES_TOOL_PROP'],
          formConfig: {
            labelWidth: 140,
            schemas: searchForms['MES_TOOL_PROP'],
            submitFunc: () => Search('PROP_NAME', data, args[0]), //自定义查询提交按钮的方法，触发查询提交事件
          },
          useSearchForm: true,
          showTableSetting: false,
          bordered: true,
          canResize: true,
          showIndexColumn: false,
          actionColumn: {
            width: 130,
            title: '操作',
            dataIndex: 'action',
            slots: { customRender: 'action' },
            fixed: 'right',
          }, //自定义操作列
        })
      };
    },
    /**
     * @description: 表格查询回调，父组件中通过子组件触发的事件获取传入的值，做具体的查询逻辑实现
     * @param {*} d
     * @return {*}
     */
    //提交查询
    FormSearch: (d) => {
      let data = {} as any;
      switch (d.type) {
        case 'MES_TOOL_PROP':
          data = d.data.value[d.type].filter(
            (item) =>
              item.TOOL_CODE.includes(d.values.TOOL_CODE) || item.PROP_NAME == d.values.PROP_NAME,
          );
          if (isNullOrEmpty(d.values.TOOL_CODE) && isNullOrEmpty(d.values.PROP_NAME)) {
            data = d.data.value[d.type];
          }
          break;
      }
      return data;
    },
    //
    KeyFieldValues: (val: string, id: string) => {
      return { TOOL_CODE: val };
    } /**
     * @description: 自定义明细表中编辑返回方法
     * @param {string} type
     * @param {*} d
     * @param {*} u
     * @return {*}
     */,
    EditOperation: (data: Ref<any[]>, d, u, item) => {
      //更新
      var _data = data.value[item].map((item) => {
        if (item['ID'] == d.ID)
          return {
            ...item,
            TOOL_CODE: d.TOOL_CODE,
            PROP_NAME: d.PROP_NAME,
           // DFT_LEVEL: d.DFT_LEVEL,
            REMARK: d.REMARK,
          };
        return item;
      });
      EditOperation(data,d, u, item, _data);
    },
    /**
     * @description: 获取标题信息
     * @param {string} type
     * @return {*}
     */
    GetTitle: () => {
      return {
        pageTitle: '生产工具管理',
        pageContent: '这里可以添加和修改生产工具管理和生产工具属性管理。',
        tableTitle: {
          MES_TOOL_PROP: '生产工具管理',
        }
      };
    },
    GetUseForm: () => {
      return {};
    },
  };

  /* 以下是内部方法，不export，供上面的方法调用 */
  // 列表
  const baseColumns = {
    MES_TOOL_PROP: [
      {
        title: '工具编码',
        dataIndex: 'TOOL_CODE',
      },
      {
        title: '点检项目名称',
        dataIndex: 'PROP_NAME',
      },
      {
        title: '备注',
        dataIndex: 'REMARK',
      },
      {
        title: '更新时间',
        dataIndex: 'UPDATE_TIME',
      },
      {
        title: '更新人',
        dataIndex: 'UPDATE_USER',
      },
    ]
  }

  const searchForms = {
    MES_TOOL_PROP: [
      {
        label: '点检项目名称',
        field: 'PROP_NAME',
        component: 'Input',
        colProps: {
          span: 8,
        },
      },
    ] as FormSchema[],
  }
  //列表信息 --新增
  const crudForms = {
    MES_TOOL_PROP: [
      {
        field: 'TOOL_CODE',
        label: '工具编码',
        component: 'Input',
        required: true,
        colProps: {
          span: 24,
        },
        //只读
        dynamicDisabled: ({ values }) => {
          return true;
        },
      },
      {
        label: '工具属性名称',
        field: 'PROP_NAME',
        component: 'Input',
        required: true,
        colProps: {
          span: 24,
        },
      },
      {
        label: '展示的控件',
        field: 'PROP_CONTROL',
        component: 'Input',
        colProps: {
          span: 24,
        },
      },
      {
        field: 'VALUE_TYPE',
        label: '属性值类型',
        component: 'ApiSelect',
        colProps: { span: 12 },
        defaultValue: 0,
        componentProps: {
          api: GetEnum,
          params: { name: 'MES_TOOL_PROP+VALUE_TYPEs' },
          resultField: 'Data',
          labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
          valueField: 'Value',
          // onChange: (e, v) => {
          //   alert(e)
          //   console.log('ApiSelect====>:', e, v);
          // },
        },
      },
      {
        label: '是否只读(Y/N)',
        field: 'READONLY',
        component: 'Select',
        colProps: {
          span: 24,
        },
        componentProps: {
          options: [
            {
              label: '是',
              value: 'Y',
              key: 'Y',
            },
            {
              label: '否',
              value: 'N',
              key: 'N',
            },
          ],
        },
      },
      {
        label: '是否显示(Y/N)',
        field: 'VISIABLE',
        component: 'Select',
        colProps: {
          span: 24,
        },
        componentProps: {
          options: [
            {
              label: '是',
              value: 'Y',
              key: 'Y',
            },
            {
              label: '否',
              value: 'N',
              key: 'N',
            },
          ],
        },
      },
      {
        label: '是否必填(Y/N)',
        field: 'NECESSARY',
        component: 'Select',
        colProps: {
          span: 24,
        },
        componentProps: {
          options: [
            {
              label: '是',
              value: 'Y',
              key: 'Y',
            },
            {
              label: '否',
              value: 'N',
              key: 'N',
            },
          ],
        },
      },
      {
        label: '备注',
        field: 'REMARK',
        component: 'Input',
        colProps: {
          span: 24,
        },
      },
      {
        label: 'ID',
        field: 'ID',
        component: 'Input',
        colProps: {
          span: 24,
        },
        show: false,
      },
    ] as FormSchema[],
  }

  return [methods, ActionColumn];
}

export default _default;
